==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основни подаци</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Додај у албум</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Све слике</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отвори слику</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Немате овлашћење да прегледате слику</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Врста</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Измењено</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Датум снимања</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експоз...</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програм експоз...</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Трајање експоз...</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Блиц</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Бленда</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Жижна даљина</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ИСО</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Највећа бленда</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим мерача</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс беле</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компензација блица</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модел сочива</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Опсег боја</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модел апарата</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Димензије</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Ознака</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Размера</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Уклопи у прозор</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Издвоји текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Напусти цео екран</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Прикажи навигациони прозор</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сакриј навигациони прозор</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>day</source>
        <translation>дан</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Потвради</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Унеси ново име</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пузирај</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Пусти</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Нису пронађене датотеке са сликама</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Датотека слике није пронађена</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.21.orig.tar.xz: image-editor-1.0.21/libimageviewer/translations/libimageviewer_sr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основни подаци</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детаљи</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Додај у албум</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нови албум</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Све слике</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отвори слику</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Уклони из албума</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Из омиљеног</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>У омиљено</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Немате овлашћење да прегледате слику</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Врста</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Измењено</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Датум снимања</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експоз...</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програм експоз...</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Трајање експоз...</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Блиц</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Бленда</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Жижна даљина</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ИСО</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Највећа бленда</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим мерача</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс беле</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компензација блица</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модел сочива</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Опсег боја</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модел апарата</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Димензије</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Ознака</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Размера</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Уклопи у прозор</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Издвоји текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ротирај улево</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ротирај удесно</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Напусти цео екран</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цео екран</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Штампај</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Покретни приказ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Прикажи навигациони прозор</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сакриј навигациони прозор</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Постави као позадину</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Својства слике</translation>
    </message>
    <message>
        <source>day</source>
        <translation>дан</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Потвради</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Унеси ново име</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Претходно</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пузирај</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Пусти</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следеће</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Нису пронађене датотеке са сликама</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Датотека слике није пронађена</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
